# Deploying ado backend services

`ado` works best when using a shared MySQL instance and running jobs on a remote
Ray cluster.

Follow the instructions to get set up:

- [Distributed MySQL backend](mysql/README.md)
- [KubeRay](kuberay/README.md)
